@@ -3,8 +3,8 @@
   FILE: icalparser.c
   CREATOR: eric 04 August 1999
   
-  $Id: icalparser.c,v 1.19 2005/09/30 14:25:35 pchen Exp $
-  $Locker:  $
+  $Id: icalparser.c 633 2008-02-18 07:26:45Z pchen $
+  $Locker$
     
  The contents of this file are subject to the Mozilla Public License
  Version 1.0 (the "License"); you may not use this file except in
@@ -623,6 +623,7 @@ icalcomponent* icalparser_parse(icalparser *parser,
 	}
     } while ( cont );
 
+    icalmemory_free_ring ();
     icalerror_set_error_state(ICAL_MALFORMEDDATA_ERROR,es);
 
     return root;
