@@ -4,7 +4,7 @@
  CREATOR: eric 02 June 2000
 
 
- $Id: icaltime.h 393 2003-10-21 18:28:34Z ettore $
+ $Id: icaltime.h 633 2008-02-18 07:26:45Z pchen $
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -180,9 +180,8 @@ time_t icaltime_as_timet(const struct icaltimetype);
 time_t icaltime_as_timet_with_zone(const struct icaltimetype tt,
 	const icaltimezone *zone);
 
-/** Return a string represention of the time, in RFC2445 format. The
-   string is owned by libical */
-const char* icaltime_as_ical_string(const struct icaltimetype tt);
+/** Return a string represention of the time, in RFC2445 format. */
+char* icaltime_as_ical_string(const struct icaltimetype tt);
 
 /** @brief Return the timezone */
 const icaltimezone *icaltime_get_timezone(const struct icaltimetype t);
