@@ -73,7 +73,7 @@ camel_pop3_engine_finalise(CamelPOP3Engine *pe)
 
 	if (pe->stream)
 		camel_object_unref(pe->stream);
-	
+
 	g_list_free(pe->auth);
 	if (pe->apop)
 		g_free(pe->apop);
@@ -105,12 +105,12 @@ read_greeting (CamelPOP3Engine *pe)
 	extern CamelServiceAuthType camel_pop3_apop_authtype;
 	unsigned char *line, *apop, *apopend;
 	unsigned int len;
-	
+
 	/* first, read the greeting */
 	if (camel_pop3_stream_line (pe->stream, &line, &len) == -1
-	    || strncmp ((char *) line, (char *) "+OK", 3) != 0)
+	    || strncmp ((char *) line, "+OK", 3) != 0)
 		return -1;
-	
+
 	if ((apop = (unsigned char *) strchr ((char *) line + 3, '<'))
 	    && (apopend = (unsigned char *) strchr ((char *) apop, '>'))) {
 		apopend[1] = 0;
@@ -118,9 +118,9 @@ read_greeting (CamelPOP3Engine *pe)
 		pe->capa = CAMEL_POP3_CAP_APOP;
 		pe->auth = g_list_append (pe->auth, &camel_pop3_apop_authtype);
 	}
-	
+
 	pe->auth = g_list_prepend (pe->auth, &camel_pop3_password_authtype);
-	
+
 	return 0;
 }
 
@@ -144,14 +144,14 @@ camel_pop3_engine_new(CamelStream *source, guint32 flags)
 	pe->stream = (CamelPOP3Stream *)camel_pop3_stream_new(source);
 	pe->state = CAMEL_POP3_ENGINE_AUTH;
 	pe->flags = flags;
-	
+
 	if (read_greeting (pe) == -1) {
 		camel_object_unref (pe);
 		return NULL;
 	}
-	
+
 	get_capabilities (pe);
-	
+
 	return pe;
 }
 
@@ -166,7 +166,7 @@ void
 camel_pop3_engine_reget_capabilities (CamelPOP3Engine *engine)
 {
 	g_return_if_fail (CAMEL_IS_POP3_ENGINE (engine));
-	
+
 	get_capabilities (engine);
 }
 
@@ -205,7 +205,7 @@ cmd_capa(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 					next = (unsigned char *) strchr((char *) tok, ' ');
 					if (next)
 						*next++ = 0;
-					auth = camel_sasl_authtype((const char *)tok);
+					auth = camel_sasl_authtype((const char *) tok);
 					if (auth) {
 						dd(printf("got auth type '%s'\n", tok));
 						pe->auth = g_list_prepend(pe->auth, auth);
@@ -228,22 +228,22 @@ static void
 get_capabilities(CamelPOP3Engine *pe)
 {
 	CamelPOP3Command *pc;
-	
+
 	if (!(pe->flags & CAMEL_POP3_ENGINE_DISABLE_EXTENSIONS)) {
 		pc = camel_pop3_engine_command_new(pe, CAMEL_POP3_COMMAND_MULTI, cmd_capa, NULL, "CAPA\r\n");
 		while (camel_pop3_engine_iterate(pe, pc) > 0)
 			;
 		camel_pop3_engine_command_free(pe, pc);
-		
+
 		if (pe->state == CAMEL_POP3_ENGINE_TRANSACTION && !(pe->capa & CAMEL_POP3_CAP_UIDL)) {
 			/* check for UIDL support manually */
 			pc = camel_pop3_engine_command_new (pe, CAMEL_POP3_COMMAND_SIMPLE, NULL, NULL, "UIDL 1\r\n");
 			while (camel_pop3_engine_iterate (pe, pc) > 0)
 				;
-			
+
 			if (pc->state == CAMEL_POP3_COMMAND_OK)
 				pe->capa |= CAMEL_POP3_CAP_UIDL;
-			
+
 			camel_pop3_engine_command_free (pe, pc);
 		}
 	}
@@ -257,24 +257,24 @@ engine_command_queue(CamelPOP3Engine *pe, CamelPOP3Command *pc)
 	    && pe->current != NULL) {
 		e_dlist_addtail(&pe->queue, (EDListNode *)pc);
 		return FALSE;
-	} else {
-		/* ??? */
-		if (camel_stream_write((CamelStream *)pe->stream, pc->data, strlen(pc->data)) == -1) {
-			e_dlist_addtail(&pe->queue, (EDListNode *)pc);
-			return FALSE;
-		}
-
-		pe->sentlen += strlen(pc->data);
-
-		pc->state = CAMEL_POP3_COMMAND_DISPATCHED;
-
-		if (pe->current == NULL)
-			pe->current = pc;
-		else
-			e_dlist_addtail(&pe->active, (EDListNode *)pc);
-
-		return TRUE;
 	}
+
+	/* ??? */
+	if (camel_stream_write((CamelStream *)pe->stream, pc->data, strlen(pc->data)) == -1) {
+		e_dlist_addtail(&pe->queue, (EDListNode *)pc);
+		return FALSE;
+	}
+
+	pe->sentlen += strlen(pc->data);
+
+	pc->state = CAMEL_POP3_COMMAND_DISPATCHED;
+
+	if (pe->current == NULL)
+		pe->current = pc;
+	else
+		e_dlist_addtail(&pe->active, (EDListNode *)pc);
+
+	return TRUE;
 }
 
 /* returns -1 on error (sets errno), 0 when no work to do, or >0 if work remaining */
@@ -331,10 +331,11 @@ camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 
 	/* Set next command */
 	pe->current = (CamelPOP3Command *)e_dlist_remhead(&pe->active);
-	
+
 	/* check the queue for sending any we can now send also */
 	pw = (CamelPOP3Command *)pe->queue.head;
 	pn = pw->next;
+
 	while (pn) {
 		if (((pe->capa & CAMEL_POP3_CAP_PIPE) == 0 || (pe->sentlen + strlen(pw->data)) > CAMEL_POP3_SEND_LIMIT)
 		    && pe->current != NULL)
@@ -394,7 +395,7 @@ camel_pop3_engine_command_new(CamelPOP3Engine *pe, guint32 flags, CamelPOP3Comma
 	pc->func = func;
 	pc->func_data = data;
 	pc->flags = flags;
-	
+
 	va_start(ap, fmt);
 	pc->data = g_strdup_vprintf(fmt, ap);
 	pc->state = CAMEL_POP3_COMMAND_IDLE;
